class GeoLocation:
    def __init__(self, latitude, longitude):
        self.latitude = latitude
        self.longitude = longitude

    def __repr__(self):
        return f"GeoLocation(latitude={self.latitude}, longitude={self.longitude})"



from abc import ABC


class PropertyTrait(ABC):
    namespace = "undef#"
    local_name = "undef"

    @classmethod
    def get_uri(cls) -> str:
        """Returns the full URI combining namespace and local name."""
        return f"{cls.namespace}{cls.local_name}"

    @classmethod
    def get_short_name(cls) -> str:
        """Transforms the local name into a short name by removing 'has' or 'is' prefixes and lowercasing the initial letter."""
        name = cls.local_name
        if name.startswith("has"):
            name = name[3:]
        elif name.startswith("is"):
            name = name[2:]

        # Lowercase the first letter and return
        return name[0].lower() + name[1:] if name else name



from vital_ai_vitalsigns.model.trait.PropertyTrait import PropertyTrait


class PropertyHasBirthday(PropertyTrait):
    namespace = "http://vital.ai/ontology/vital-core#"
    local_name = "hasBirthday"



from setuptools import setup, find_packages

setup(
    name='vital-ai-vitalsigns',
    version='0.1.0',
    author='Marc Hadfield',
    author_email='marc@vital.ai',
    description='VitalSigns knowledge graph bindings',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/vital-ai/vital-vitalsigns-python',
    packages=find_packages(),
    license='Apache License 2.0',
    classifiers=[
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.12',
)